@@ -84,12 +84,12 @@ class Fiber_set(Object_set):
 
         # print(len(filaments))
 
-    def analyze(self, fiber, analyze={}, *args, **kwargs):
+    def analyze(self, fiber, analyzer=None, *args, **kwargs):
 
-        #analysis = {'id': fiber.id}
         analysis = {}
-        for name, func in analyze.items():
-            analysis[name] = func(fiber)
+        if analyzer is not None:
+            for name, func in analyzer.items():
+                analysis[name] = func(fiber)
 
         analysis['deformation_energy'] = self.compute_deformation_energy(fiber, *args,  **kwargs)
 
