@@ -31,10 +31,11 @@ class Object_set(list):
         self.append(Object(None))
 
     # Generic analyzer
-    def analyze(self, obj, analyze={}, *args, **kwargs):
+    def analyze(self, obj, analyzer=None, *args, **kwargs):
         analysis={}
-        for name, func in analyze.items():
-            analysis[name] = func(obj)
+        if analyzer is not None:
+            for name, func in analyzer.items():
+                analysis[name] = func(obj)
 
         return analysis
 
